@@ -12,6 +12,10 @@ class Distro(Module):
 
     register = 'download'
 
+    @property
+    def label(self):
+        return 'Download'
+
     def deploy(self, target, **kw):
         url, dst = kw['url'], kw.get('dst')
         dst = dst or 'downloaded'
@@ -21,7 +25,8 @@ class Distro(Module):
                 raise RuntimeError
         except:
             try:
-                ret, out, err = target.run(f'curl -sfL {url} -o {dst}')
+                # curl >= 7.75
+                ret, out, err = target.run(f'curl -sfL -w "%{{errormsg}}\n" {url} -o {dst}')
                 if ret!=0:
                     raise RuntimeError
             except:
@@ -30,8 +35,8 @@ class Distro(Module):
                     if ret!=0:
                         raise RuntimeError
                 except:
-                    target.Packag.install('curl')
-                    ret, out, err = target.run(f'curl -sfL {url} -o {dst}')
+                    target.Package.install('wget')
+                    ret, out, err = target.run(f'wget -q {url} -O {dst}')
                     if ret!=0:
                         msg = err[0]
                         error(msg)
